﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Net;
using System.Text;
using ThinkGeo.Core;
using ThinkGeo.UI.XamarinForms;
using Xamarin.Essentials;

namespace GoogleCache
{
    public static class MapHelper
    {
        public static void InitilizeMapView(MapView mapView)
        {
            try
            {
                mapView.MapUnit = GeographyUnit.Meter;
                mapView.CurrentExtent = new RectangleShape(-10786436, 3918518, -10769429, 3906002);
            }
            catch (Exception ex)
            {
                Debug.WriteLine(ex.StackTrace);
            }

            mapView.RefreshAsync();
        }

        public static void SetupGoogleMapOverlay(MapView mapView)
        {
            try
            {
                mapView.ZoomLevelSet = new SphericalMercatorZoomLevelSet();

                GoogleMapsLayer layer = new GoogleMapsLayer(Constants.GoogleMapApiKey); // set your key in constants file
                layer.PictureFormat = GoogleMapsPictureFormat.Jpeg;
                layer.MapType = GoogleMapsMapType.Hybrid;
                layer.DrawingException += Layer_DrawingException;

                LayerOverlay layerOverlay = new LayerOverlay();
                layerOverlay.TileType = TileType.MultiTile;
                layerOverlay.DrawingQuality = DrawingQuality.HighSpeed;
                layerOverlay.Layers.Add(layer);
                var current = Connectivity.NetworkAccess;

                //if (current != NetworkAccess.Internet)
                //{
                    layerOverlay.TileCache = new FileRasterTileCache( GetTileCacheFolder(), "google");
                //}
                mapView.Overlays.Add(Constants.BACKGROUND_OVERLAY, layerOverlay);
                mapView.RefreshAsync();
            }
            catch (Exception e)
            {

            }
        }

        private static void Layer_DrawingException(object sender, DrawingExceptionLayerEventArgs e)
        {
            if (e.Exception is System.ArgumentNullException)
                e.Cancel = true;

            if (e.Exception is WebException)
                e.Cancel = true;
        }


        public static string GetTileCacheFolder()
        {
            var path = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData), "googlecache");
            if (!Directory.Exists(path))
            {
                Directory.CreateDirectory(path);
            }

            return path;
        }
    }
}
